/**
 * Copyright (c) 2012 - 2020 Data In Motion and others.
 * All rights reserved. 
 * 
 * This program and the accompanying materials are made available under the terms of the 
 * Eclipse Public License v1.0 which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Data In Motion - initial API and implementation
 */
package org.gecko.core.api.connection;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.Map;

/**
 * 
 * @author mark
 * @since 28.04.2020
 */
public interface DeSerializer<T> {
	
	/**
	 * Returns <code>true</code>, if this instance can serialize
	 * @return <code>true</code>, if this instance can serialize
	 */
	public boolean canSerialize();
	
	/**
	 * Serializes the given object using the options map
	 * @param object the to be serialized
	 * @param output output stream
	 * @param options additional serialization options
	 * @return an {@link OutputStream} or <code>null</code> if there is nothing to serialize
	 */
	public void serialize(T object, OutputStream output, Map<String, Object> options);
	
	/**
	 * Returns <code>true</code>, if this instance can de-serialize
	 * @return <code>true</code>, if this instance can de-serialize
	 */
	public boolean canDeserialize();
	
	/**
	 * De-serializes the given {@link InputStream} using the given additional options
	 * @param input the {@link InputStream}
	 * @param options the additional options map
	 * @return the de-serialized object
	 */
	public T deserialize(InputStream input, Map<String, Object> options);

}
